/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*                       DIRECCIN DE PRUEBAS Y MEDICIN
/*                           SUBDIRECCION DE ANLISIS
/*_____________________________________________________________________________
/*
/*            EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                TERCER GRADO DE PREESCOLAR (Excale 00)
/*
/*                          **** ESCUELAS ****
/*
/*                     Ciclo escolar evaluado: 2010 - 2011
/*_____________________________________________________________________________
/*
/*
/*            PROGRAMA PARA CONSTRUIR LA BASE DE DATOS DE ESCUELAS
/*                               EN FORMATO SAS
/*_____________________________________________________________________________
/*
/*  El programa convierte el archivo Excale00_2011_Escuelas.txt el cual est en
/*  formato ASCII a una base de datos en formato SAS. El programa realiza las
/*  siguientes tareas:
/*   - Declara formatos para algunas variables
/*   - Lee las variables del archivo en formato ASCII
/*   - Declara los valores considerados en el anlisis como perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale00_2011_Escuelas.txt
/*         as como el archivo Excale00_2011_Escuelas.SAS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE (www.inee.edu.mx).
/*      2) Modificar la primera y segunda lnea de los comandos de este archivo
/*         (libname y filename) para actualizar el nombre de la librera y el archivo
/*         de trabajo.
/*      3) Ejecutar el programa del archivo.
/*
/*  Al finalizar, se deber contar con la base de datos (tabla de datos) Excale00_2011_Escuelas.sas7bdat
/*
/*  Posteriormente, cuando se desee utilizar nuevamente la base Excale00_2011_Escuelas.sas7bdat,
/*  se deber ejecutar primero el procedimiento FORMAT ("proc FORMAT") de este programa para que
/*  SAS cargue los formatos necesarios para abrir la base.
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Subdireccin de Anlisis del Instituto
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 1082
/*      Domicilio: Jos Ma. Velasco No. 101. 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/* FECHA DE LIBERACIN: 27 DE AGOSTO DE 2013
/*
/*  ****************************************************************************/


LIBNAME  INEE  "C:\***\";
FILENAME esc   "C:\***\Excale00_2011_Escuelas.TXT";

PROC FORMAT;
     VALUE id_entF     1         ="Aguascalientes"
                       2         ="Baja California"
                       3         ="Baja California Sur"
                       4         ="Campeche"
                       5         ="Coahuila"
                       6         ="Colima"
                       7         ="Chiapas"
                       8         ="Chihuahua"
                       9         ="Distrito Federal"
                       10        ="Durango"
                       11        ="Guanajuato"
                       12        ="Guerrero"
                       13        ="Hidalgo"
                       14        ="Jalisco"
                       15        ="Mxico"
                       16        ="Michoacn"
                       17        ="Morelos"
                       18        ="Nayarit"
                       19        ="Nuevo Len"
                       20        ="Oaxaca"
                       21        ="Puebla"
                       22        ="Quertaro"
                       23        ="Quintana Roo"
                       24        ="San Luis Potos"
                       25        ="Sinaloa"
                       26        ="Sonora"
                       27        ="Tabasco"
                       28        ="Tamaulipas"
                       29        ="Tlaxcala"
                       30        ="Veracruz"
                       31        ="Yucatn"
                       32        ="Zacatecas";
     VALUE id_turnF    1         ="Matutino"
                       2         ="Vespertino"
                       3         ="Nocturno"
                       4         ="Discontinuo"
                       5         ="Mixto";
     VALUE id_modF     1         ="Urbano Pblico"
                       2         ="Rural Pblico"
                       3         ="Educacin Indgena"
                       4         ="Cursos Comunitarios"
                       5         ="Privados";
     VALUE $modF       "UP"      ="Urbano Pblico"
                       "RP"      ="Rural Pblico"
                       "EI"      ="Educacin Indgena"
                       "CC"      ="Cursos Comunitarios"
                       "UPV"     ="Privados"
                       "PUB"     ="Escuelas pblicas sin clasificar en Urbanas o Rurales. Slo se utilizan para estimacin de parmetros a nivel Nacional";
RUN;



DATA INEE.Excale00_2011_Escuelas;
   LENGTH
       PROYECTO           $10
       ANIO               4
       ID_ENT             3
       NOM_ENT            $19
       ESCUELA            4
       ID_TURNO           3
       TURNO_ESC          $12
       ESTRATO            $6
       ID_MOD             3
       MOD                $4
       ALU_ESC            4
       ALU_SHI            3
       ESC_UH             5

   ;


INFILE esc MISSOVER LINESIZE = 74;
   INPUT
        PROYECTO          1 - 10
        ANIO              11 - 14
        ID_ENT           15 - 16
        NOM_ENT          17 - 35
        ESCUELA          36 - 39
        ID_TURNO         40 - 40
        TURNO_ESC        41 - 52
        ESTRATO          53 - 58
        ID_MOD           59 - 59
        MOD              60 - 63
        ALU_ESC          64 - 67
        ALU_SHI          68 - 69
        ESC_UH           70 - 74
   ;

   LABEL
      PROYECTO     ="Proyecto al que pertenece el estudio"
      ANIO          ="Ao del levantamiento de datos"
      ID_ENT       ="Entidad federativa (identificador numrico)"
      NOM_ENT      ="Entidad federativa"
      ESCUELA      ="Identificador de la escuela"
      ID_TURNO     ="Turno de la escuela (numrico)"
      TURNO_ESC    ="Turno de la escuela"
      ESTRATO      ="Estratos del diseo muestral con el que se estiman los parmetros y errores estndar"
      ID_MOD       ="Estrato escolar o Modalidad educativa (identificador numrico)"
      MOD          ="Estrato escolar o Modalidad educativa"
      ALU_ESC      ="Cantidad de alumnos de 3o de preescolar en la escuela"
      ALU_SHI      ="Cantidad de alumnos evaluados en la escuela"
      ESC_UH       ="Cantidad de escuelas en el estrato muestral"
 ;

   FORMAT
        id_ent            id_entF.
        id_turno          id_turnF.
        id_mod            id_modF.
        mod               $modF.
   ;


/**************************************************************************
/*  Definicin de valores perdidos
/*************************************************************************/




RUN;



